@@ -1,8 +1,8 @@
 #ifndef S7_H
 #define S7_H
 
-#define S7_VERSION "9.6"
-#define S7_DATE "14-10-2020"
+#define S7_VERSION "9.7"
+#define S7_DATE "23-11-2020"
 
 #include <stdint.h>           /* for int64_t */
 
@@ -69,6 +69,8 @@ char *s7_object_to_c_string(s7_scheme *sc, s7_pointer obj);          /* same as
 
 s7_pointer s7_load(s7_scheme *sc, const char *file);                 /* (load file) */
 s7_pointer s7_load_with_environment(s7_scheme *sc, const char *filename, s7_pointer e);
+s7_pointer s7_load_c_string(s7_scheme *sc, const char *content, s7_int bytes);
+s7_pointer s7_load_c_string_with_environment(s7_scheme *sc, const char *content, s7_int bytes, s7_pointer e);
 s7_pointer s7_load_path(s7_scheme *sc);                              /* *load-path* */
 s7_pointer s7_add_to_load_path(s7_scheme *sc, const char *dir);      /* (set! *load-path* (cons dir *load-path*)) */
 s7_pointer s7_autoload(s7_scheme *sc, s7_pointer symbol, s7_pointer file_or_function);  /* (autoload symbol file-or-function) */
@@ -886,9 +888,10 @@ typedef s7_double s7_Double;
  * 
  *        s7 changes
  *
+ * 14-Oct:    s7_load_c_string and s7_load_c_string_with_environment.
  * 10-Sep:    s7_free.
  * 5-Aug:     s7_make_list.
- * 31-July:   add s7_define_constant_with_environment and s7_dilambda_with_environment.
+ * 31-July:   s7_define_constant_with_environment and s7_dilambda_with_environment.
  * 29-July:   open-input|output-function. add S7_NUM_READ_CHOICES to s7_read_t enum and remove (unused) S7_READ_BYTE.
  * 20-July:   s7_c_pointer_with_type. notcurses_s7.c and nrepl.scm. *autoload-hook*. 
  * 8-July:    s7_int|float_vector_ref|set. subvector parameter order changed.
